# -------------------------------------------------------------------------------------------
#
# How to build for UP kernel
#
#  rpmbuild -ba --target i686   --define 'kernel 2.6.9-55.EL' madwifi.spec
#  rpmbuild -ba --target x86_64 --define 'kernel 2.6.9-55.EL' madwifi.spec
#
# How to build for UP and SMP kernel
#
#  rpmbuild -ba --target i686   --define 'kernel 2.6.9-55.EL' --define 'buildsmp 1' madwifi.spec
#  rpmbuild -ba --target x86_64 --define 'kernel 2.6.9-55.EL' --define 'buildsmp 1' madwifi.spec
#
# How to build for all kernels (UP, SMP, hugemem/largesmp)
#
#  rpmbuild -ba --target i686   --define 'kernel 2.6.9-55.EL' --define 'buildall 1' madwifi.spec
#  rpmbuild -ba --target x86_64 --define 'kernel 2.6.9-55.EL' --define 'buildall 1' madwifi.spec
#
# -------------------------------------------------------------------------------------------

%{!?buildsmp:%define buildsmp 0}
%{!?buildxenU:%define buildxenU 0}
%{!?buildhugemem:%define buildhugemem 0}
%{!?buildlargesmp:%define buildlargesmp 0}

%{?buildall:%define buildsmp 1}
## madwifi does not build for xenU kernel
## _{?buildall:_define buildxenU 1}
%{?buildall:%define buildhugemem 1}
%{?buildall:%define buildlargesmp 1}

%ifarch x86_64
%define buildhugemem 0
%endif

%ifarch i686
%define buildlargesmp 0
%endif

%{?!kernel:%define kernel %(rpm -q kernel-devel | tail -1 | sed -e 's|kernel-devel-||')}

%define kversion %(echo "%{kernel}" | sed -e 's|-.*||')
%define krelease %(echo "%{kernel}" | sed -e 's|.*-||')

%define kernel_src_path          /lib/modules/%{kernel}/build

%define kernel_moduledir          /lib/modules/%{kernel}/kernel/drivers/net/wireless/madfiwi

%define pkg_name madwifi
%define kmdl_name kernel-module-%{pkg_name}-%{kernel}
%define kmdl_name_hal kernel-module-%{pkg_name}-hal-%{kernel}

Summary: 	A linux device driver for Atheros chipsets (ar5210, ar5211, ar5212).
Name: 		%{pkg_name}
Version: 	0.9.4
Epoch:	        1
Release: 	10.sl4
Packager: 	Urs Beyerle <urs.beyerle@psi.ch>
License: 	proprietary
Group: 		System Environment/Kernel
URL: 		http://madwifi.org/
Source0: 	%{pkg_name}-%{version}.tar.gz
BuildRoot: 	%{_tmppath}/%{name}-%{version}-%{release}-buildroot
BuildRequires: 	/usr/bin/uudecode
Requires:       kernel-module-%{pkg_name} >= %{version}-%{release}
#BuildRequires:  kernel-devel = %{kernel}
#%if %{buildsmp}
#BuildRequires:  kernel-smp-devel = %{kernel}
#%endif
#%if %{buildxenU}
#BuildRequires:  kernel-xenU-devel = %{kernel}
#%endif
#%if %{buildhugemem}
#BuildRequires:  kernel-hugemem-devel = %{kernel}
#%endif
#%if %{buildlargesmp}
#BuildRequires:  kernel-largesmp-devel = %{kernel}
#%endif

%description
This package contains the Multiband Atheros Driver for WiFi, A linux
device driver for 802.11a/b/g universal NIC cards - either Cardbus,
PCI or MiniPCI - that use Atheros chipsets (ar5210, ar5211, ar5212).

%package -n %{kmdl_name}
Summary: 	A linux device driver for Atheros chipsets (ar5210, ar5211, ar5212).
Group: 		System Environment/Kernel
License: 	GPL/BSD
Provides:       kernel-module-%{pkg_name} = %{epoch}:%{version}-%{release}
Requires: 	%{kmdl_name_hal} = %{epoch}:%{version}

%description -n %{kmdl_name}
This package contains the Multiband Atheros Driver for WiFi, A linux
device driver for 802.11a/b/g universal NIC cards - either Cardbus,
PCI or MiniPCI - that use Atheros chipsets (ar5210, ar5211, ar5212).

This kernel module contains the GPL/BSD components of madwifi.

%package -n %{kmdl_name_hal}
Summary: 	A linux device driver for Atheros chipsets (ar5210, ar5211, ar5212).
Group: 		System Environment/Kernel
License: 	proprietary
Provides:       kernel-module-%{pkg_name} = %{epoch}:%{version}-%{release}
Requires: 	%{kmdl_name} = %{epoch}:%{version}

%description -n %{kmdl_name_hal}
This package contains the Multiband Atheros Driver for WiFi, A linux
device driver for 802.11a/b/g universal NIC cards - either Cardbus,
PCI or MiniPCI - that use Atheros chipsets (ar5210, ar5211, ar5212).

This kernel module contains the HAL components of madwifi.


%if %{buildsmp}

%package -n %{kmdl_name}smp
Summary: 	A linux device driver for Atheros chipsets (ar5210, ar5211, ar5212).
Group: 		System Environment/Kernel
License: 	GPL/BSD
Provides:       kernel-module-%{pkg_name} = %{epoch}:%{version}-%{release}
Requires: 	%{kmdl_name_hal}smp = %{epoch}:%{version}

%description -n %{kmdl_name}smp
This package contains the Multiband Atheros Driver for WiFi, A linux
device driver for 802.11a/b/g universal NIC cards - either Cardbus,
PCI or MiniPCI - that use Atheros chipsets (ar5210, ar5211, ar5212).

This kernel module contains the GPL/BSD components of madwifi.

%package -n %{kmdl_name_hal}smp
Summary: 	A linux device driver for Atheros chipsets (ar5210, ar5211, ar5212).
Group: 		System Environment/Kernel
License: 	proprietary
Provides:       kernel-module-%{pkg_name} = %{epoch}:%{version}-%{release}
Requires: 	%{kmdl_name}smp = %{epoch}:%{version}

%description -n %{kmdl_name_hal}smp
This package contains the Multiband Atheros Driver for WiFi, A linux
device driver for 802.11a/b/g universal NIC cards - either Cardbus,
PCI or MiniPCI - that use Atheros chipsets (ar5210, ar5211, ar5212).

This kernel module contains the HAL components of madwifi.

%endif


%if %{buildxenU}

%package -n %{kmdl_name}xenU
Summary: 	A linux device driver for Atheros chipsets (ar5210, ar5211, ar5212).
Group: 		System Environment/Kernel
License: 	GPL/BSD
Provides:       kernel-module-%{pkg_name} = %{epoch}:%{version}-%{release}
Requires: 	%{kmdl_name_hal}xenU = %{epoch}:%{version}

%description -n %{kmdl_name}xenU
This package contains the Multiband Atheros Driver for WiFi, A linux
device driver for 802.11a/b/g universal NIC cards - either Cardbus,
PCI or MiniPCI - that use Atheros chipsets (ar5210, ar5211, ar5212).

This kernel module contains the GPL/BSD components of madwifi.

%package -n %{kmdl_name_hal}xenU
Summary: 	A linux device driver for Atheros chipsets (ar5210, ar5211, ar5212).
Group: 		System Environment/Kernel
License: 	proprietary
Provides:       kernel-module-%{pkg_name} = %{epoch}:%{version}-%{release}
Requires: 	%{kmdl_name}xenU = %{epoch}:%{version}

%description -n %{kmdl_name_hal}xenU
This package contains the Multiband Atheros Driver for WiFi, A linux
device driver for 802.11a/b/g universal NIC cards - either Cardbus,
PCI or MiniPCI - that use Atheros chipsets (ar5210, ar5211, ar5212).

This kernel module contains the HAL components of madwifi.

%endif


%if %{buildhugemem}

%package -n %{kmdl_name}hugemem
Summary: 	A linux device driver for Atheros chipsets (ar5210, ar5211, ar5212).
Group: 		System Environment/Kernel
License: 	GPL/BSD
Provides:       kernel-module-%{pkg_name} = %{epoch}:%{version}-%{release}
Requires: 	%{kmdl_name_hal}hugemem = %{epoch}:%{version}

%description -n %{kmdl_name}hugemem
This package contains the Multiband Atheros Driver for WiFi, A linux
device driver for 802.11a/b/g universal NIC cards - either Cardbus,
PCI or MiniPCI - that use Atheros chipsets (ar5210, ar5211, ar5212).

This kernel module contains the GPL/BSD components of madwifi.

%package -n %{kmdl_name_hal}hugemem
Summary: 	A linux device driver for Atheros chipsets (ar5210, ar5211, ar5212).
Group: 		System Environment/Kernel
License: 	proprietary
Provides:       kernel-module-%{pkg_name} = %{epoch}:%{version}-%{release}
Requires: 	%{kmdl_name}hugemem = %{epoch}:%{version}

%description -n %{kmdl_name_hal}hugemem
This package contains the Multiband Atheros Driver for WiFi, A linux
device driver for 802.11a/b/g universal NIC cards - either Cardbus,
PCI or MiniPCI - that use Atheros chipsets (ar5210, ar5211, ar5212).

This kernel module contains the HAL components of madwifi.

%endif


%if %{buildlargesmp}

%package -n %{kmdl_name}largesmp
Summary: 	A linux device driver for Atheros chipsets (ar5210, ar5211, ar5212).
Group: 		System Environment/Kernel
License: 	GPL/BSD
Provides:       kernel-module-%{pkg_name} = %{epoch}:%{version}-%{release}
Requires: 	%{kmdl_name_hal}largesmp = %{epoch}:%{version}

%description -n %{kmdl_name}largesmp
This package contains the Multiband Atheros Driver for WiFi, A linux
device driver for 802.11a/b/g universal NIC cards - either Cardbus,
PCI or MiniPCI - that use Atheros chipsets (ar5210, ar5211, ar5212).

This kernel module contains the GPL/BSD components of madwifi.

%package -n %{kmdl_name_hal}largesmp
Summary: 	A linux device driver for Atheros chipsets (ar5210, ar5211, ar5212).
Group: 		System Environment/Kernel
License: 	proprietary
Provides:       kernel-module-%{pkg_name} = %{epoch}:%{version}-%{release}
Requires: 	%{kmdl_name}largesmp = %{epoch}:%{version}

%description -n %{kmdl_name_hal}largesmp
This package contains the Multiband Atheros Driver for WiFi, A linux
device driver for 802.11a/b/g universal NIC cards - either Cardbus,
PCI or MiniPCI - that use Atheros chipsets (ar5210, ar5211, ar5212).

This kernel module contains the HAL components of madwifi.

%endif


%prep
%setup -n %{pkg_name}-%{version}
find . -name Makefile\* | xargs perl -pi -e's,/sbin/depmod,: /sbin/depmod,'

%build
echo -e "\nDriver version: %{version}\nKernel version: %{kernel}\n"

export TOOLPREFIX=`which gcc|sed -e's,gcc$,,'`
%ifarch %x86
export TARGET=i386-elf
%endif
%ifarch x86_64
export TARGET=x86_64-elf
%endif

# export COPTS="$COPTS -DNO_WME"

mkdir -p %{buildroot}%{_bindir}

### build tools
%{__make} clean
%{__make} -C tools \
     KERNELPATH=%{kernel_src_path} \
     KERNELRELEASE=%{kernel}

%{__make} -C tools install DESTDIR=%{buildroot} \
     BINDIR=%{_bindir} MANDIR=%{_mandir} \
     KERNELPATH=%{kernel_src_path} \
     KERNELRELEASE=%{kernel}

mv hal/COPYRIGHT hal/COPYRIGHT.hal
mv hal/README hal/README.hal


### UP kernel
%{__make} clean
%{__make} modules KERNELPATH=%{kernel_src_path} \
     KERNELRELEASE=%{kernel}

export KERNELPATH=%{kernel_src_path}
export KERNELRELEASE=%{kernel}
mkdir -p %{buildroot}%{kernel_moduledir}
%{__make} KERNELPATH=%{kernel_src_path} \
     KERNELRELEASE=%{kernel} \
     DESTDIR=%{buildroot} \
     KMODPATH=%{kernel_moduledir} \
     MODULEPATH=%{kernel_moduledir} \
     install-modules


%if %{buildsmp}

### SMP kernel 
%{__make} clean
%{__make} modules KERNELPATH=%{kernel_smp_src_path} \
     KERNELRELEASE=%{kernel}smp

export KERNELPATH=%{kernel_smp_src_path}
export KERNELRELEASE=%{kernel}smp
mkdir -p %{buildroot}%{kernel_smp_moduledir}
%{__make} KERNELPATH=%{kernel_smp_src_path} \
     KERNELRELEASE=%{kernel}smp \
     DESTDIR=%{buildroot} \
     KMODPATH=%{kernel_smp_moduledir} \
     MODULEPATH=%{kernel_smp_moduledir} \
     install-modules

%endif


%if %{buildxenU}

### Xen kernel 
%{__make} clean
%{__make} modules KERNELPATH=%{kernel_xenU_src_path} \
     KERNELRELEASE=%{kernel}xenU

export KERNELPATH=%{kernel_xenU_src_path}
export KERNELRELEASE=%{kernel}xenU
mkdir -p %{buildroot}%{kernel_xenU_moduledir}
%{__make} KERNELPATH=%{kernel_xenU_src_path} \
     KERNELRELEASE=%{kernel}xenU \
     DESTDIR=%{buildroot} \
     KMODPATH=%{kernel_xenU_moduledir} \
     MODULEPATH=%{kernel_xenU_moduledir} \
     install-modules

%endif


%if %{buildhugemem}

### HUGEMEM kernel 
%{__make} clean
%{__make} modules KERNELPATH=%{kernel_hugemem_src_path} \
     KERNELRELEASE=%{kernel}hugemem

export KERNELPATH=%{kernel_hugemem_src_path}
export KERNELRELEASE=%{kernel}hugemem
mkdir -p %{buildroot}%{kernel_hugemem_moduledir}
%{__make} KERNELPATH=%{kernel_hugemem_src_path} \
     KERNELRELEASE=%{kernel}hugemem \
     DESTDIR=%{buildroot} \
     KMODPATH=%{kernel_hugemem_moduledir} \
     MODULEPATH=%{kernel_hugemem_moduledir} \
     install-modules

%endif


%if %{buildlargesmp}

### LARGESMP kernel 
%{__make} clean
%{__make} modules KERNELPATH=%{kernel_largesmp_src_path} \
     KERNELRELEASE=%{kernel}largesmp

export KERNELPATH=%{kernel_largesmp_src_path}
export KERNELRELEASE=%{kernel}largesmp
mkdir -p %{buildroot}%{kernel_largesmp_moduledir}
%{__make} KERNELPATH=%{kernel_largesmp_src_path} \
     KERNELRELEASE=%{kernel}largesmp \
     DESTDIR=%{buildroot} \
     KMODPATH=%{kernel_largesmp_moduledir} \
     MODULEPATH=%{kernel_largesmp_moduledir} \
     install-modules

%endif


%install

%clean
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot}

%postun -n %{kmdl_name}
depmod -a %{kernel} >/dev/null 2>&1 || :

%post -n %{kmdl_name}
depmod -a %{kernel} >/dev/null 2>&1 || :

%postun -n %{kmdl_name_hal}
depmod -a %{kernel} >/dev/null 2>&1 || :

%post -n %{kmdl_name_hal}
depmod -a %{kernel} >/dev/null 2>&1 || :


%if %{buildsmp}

%postun -n %{kmdl_name}smp
depmod -a %{kernel} >/dev/null 2>&1 || :

%post -n %{kmdl_name}smp
depmod -a %{kernel} >/dev/null 2>&1 || :

%postun -n %{kmdl_name_hal}smp
depmod -a %{kernel} >/dev/null 2>&1 || :

%post -n %{kmdl_name_hal}smp
depmod -a %{kernel} >/dev/null 2>&1 || :

%endif


%if %{buildxenU}

%postun -n %{kmdl_name}xenU
depmod -a %{kernel} >/dev/null 2>&1 || :

%post -n %{kmdl_name}xenU
depmod -a %{kernel} >/dev/null 2>&1 || :

%postun -n %{kmdl_name_hal}xenU
depmod -a %{kernel} >/dev/null 2>&1 || :

%post -n %{kmdl_name_hal}xenU
depmod -a %{kernel} >/dev/null 2>&1 || :

%endif


%if %{buildhugemem}

%postun -n %{kmdl_name}hugemem
depmod -a %{kernel} >/dev/null 2>&1 || :

%post -n %{kmdl_name}hugemem
depmod -a %{kernel} >/dev/null 2>&1 || :

%postun -n %{kmdl_name_hal}hugemem
depmod -a %{kernel} >/dev/null 2>&1 || :

%post -n %{kmdl_name_hal}hugemem
depmod -a %{kernel} >/dev/null 2>&1 || :

%endif


%if %{buildlargesmp}

%postun -n %{kmdl_name}largesmp
depmod -a %{kernel} >/dev/null 2>&1 || :

%post -n %{kmdl_name}largesmp
depmod -a %{kernel} >/dev/null 2>&1 || :

%postun -n %{kmdl_name_hal}largesmp
depmod -a %{kernel} >/dev/null 2>&1 || :

%post -n %{kmdl_name_hal}largesmp
depmod -a %{kernel} >/dev/null 2>&1 || :

%endif


%files 
%defattr(-,root,root,-)
%doc COPYRIGHT README hal/COPYRIGHT.hal hal/README.hal
%doc docs/users-guide.pdf docs/WEP-HOWTO.txt
%{_bindir}/athstats
%{_bindir}/80211stats
%{_bindir}/athdebug
%{_bindir}/80211debug
%{_bindir}/athchans
%{_bindir}/athctrl
%{_bindir}/athkey
%{_bindir}/wlanconfig
%{_bindir}/ath_info

%{_mandir}/man8/80211debug.8*
%{_mandir}/man8/80211stats.8*
%{_mandir}/man8/athchans.8*
%{_mandir}/man8/athctrl.8*
%{_mandir}/man8/athdebug.8*
%{_mandir}/man8/athkey.8*
%{_mandir}/man8/athstats.8*
%{_mandir}/man8/wlanconfig.8*
%{_mandir}/man8/ath_info.8*

%files -n %{kmdl_name}
%defattr(-,root,root,-)
# %dir %{kernel_moduledir}
%{kernel_moduledir}/ath_pci.*o
%{kernel_moduledir}/ath_rate_*.*o
%{kernel_moduledir}/wlan.*o
%{kernel_moduledir}/wlan_acl.*o
%{kernel_moduledir}/wlan_ccmp.*o
%{kernel_moduledir}/wlan_tkip.*o
%{kernel_moduledir}/wlan_wep.*o
%{kernel_moduledir}/wlan_xauth.*o
%{kernel_moduledir}/wlan_scan_ap.*o
%{kernel_moduledir}/wlan_scan_sta.*o

%files -n %{kmdl_name_hal}
%defattr(-,root,root,-)
%dir %{kernel_moduledir}
%{kernel_moduledir}/ath_hal.*o


%if %{buildsmp}

%files -n %{kmdl_name}smp
%defattr(-,root,root,-)
# %dir %{kernel_smp_moduledir}
%{kernel_smp_moduledir}/ath_pci.*o
%{kernel_smp_moduledir}/ath_rate_*.*o
%{kernel_smp_moduledir}/wlan.*o
%{kernel_smp_moduledir}/wlan_acl.*o
%{kernel_smp_moduledir}/wlan_ccmp.*o
%{kernel_smp_moduledir}/wlan_tkip.*o
%{kernel_smp_moduledir}/wlan_wep.*o
%{kernel_smp_moduledir}/wlan_xauth.*o
%{kernel_smp_moduledir}/wlan_scan_ap.*o
%{kernel_smp_moduledir}/wlan_scan_sta.*o

%files -n %{kmdl_name_hal}smp
%defattr(-,root,root,-)
%dir %{kernel_smp_moduledir}
%{kernel_smp_moduledir}/ath_hal.*o

%endif


%if %{buildxenU}

%files -n %{kmdl_name}xenU
%defattr(-,root,root,-)
# %dir %{kernel_xenU_moduledir}
%{kernel_xenU_moduledir}/ath_pci.*o
%{kernel_xenU_moduledir}/ath_rate_*.*o
%{kernel_xenU_moduledir}/wlan.*o
%{kernel_xenU_moduledir}/wlan_acl.*o
%{kernel_xenU_moduledir}/wlan_ccmp.*o
%{kernel_xenU_moduledir}/wlan_tkip.*o
%{kernel_xenU_moduledir}/wlan_wep.*o
%{kernel_xenU_moduledir}/wlan_xauth.*o
%{kernel_xenU_moduledir}/wlan_scan_ap.*o
%{kernel_xenU_moduledir}/wlan_scan_sta.*o

%files -n %{kmdl_name_hal}xenU
%defattr(-,root,root,-)
%dir %{kernel_xenU_moduledir}
%{kernel_xenU_moduledir}/ath_hal.*o

%endif


%if %{buildhugemem}

%files -n %{kmdl_name}hugemem
%defattr(-,root,root,-)
# %dir %{kernel_hugemem_moduledir}
%{kernel_hugemem_moduledir}/ath_pci.*o
%{kernel_hugemem_moduledir}/ath_rate_*.*o
%{kernel_hugemem_moduledir}/wlan.*o
%{kernel_hugemem_moduledir}/wlan_acl.*o
%{kernel_hugemem_moduledir}/wlan_ccmp.*o
%{kernel_hugemem_moduledir}/wlan_tkip.*o
%{kernel_hugemem_moduledir}/wlan_wep.*o
%{kernel_hugemem_moduledir}/wlan_xauth.*o
%{kernel_hugemem_moduledir}/wlan_scan_ap.*o
%{kernel_hugemem_moduledir}/wlan_scan_sta.*o

%files -n %{kmdl_name_hal}hugemem
%defattr(-,root,root,-)
%dir %{kernel_hugemem_moduledir}
%{kernel_hugemem_moduledir}/ath_hal.*o

%endif


%if %{buildlargesmp}

%files -n %{kmdl_name}largesmp
%defattr(-,root,root,-)
# %dir %{kernel_largesmp_moduledir}
%{kernel_largesmp_moduledir}/ath_pci.*o
%{kernel_largesmp_moduledir}/ath_rate_*.*o
%{kernel_largesmp_moduledir}/wlan.*o
%{kernel_largesmp_moduledir}/wlan_acl.*o
%{kernel_largesmp_moduledir}/wlan_ccmp.*o
%{kernel_largesmp_moduledir}/wlan_tkip.*o
%{kernel_largesmp_moduledir}/wlan_wep.*o
%{kernel_largesmp_moduledir}/wlan_xauth.*o
%{kernel_largesmp_moduledir}/wlan_scan_ap.*o
%{kernel_largesmp_moduledir}/wlan_scan_sta.*o

%files -n %{kmdl_name_hal}largesmp
%defattr(-,root,root,-)
%dir %{kernel_largesmp_moduledir}
%{kernel_largesmp_moduledir}/ath_hal.*o

%endif


%changelog
* Fri Aug 08 2008 Urs Beyerle <urs.beyerle@env.ethz.ch> - 0.9.4-10
- update to 0.9.4
- add ath_info
- add dist tag in release

* Wed Feb 20 2008 Troy Dawson <dawson@fnal.gov> - 0.9.3.3-10.sl4
- Updated to 0.9.3.3

* Sat Jun 02 2007 Urs Beyerle <urs.beyerle@psi.ch> - 0.9.3.1-10.sl4.psi
- add xenU, hugemem, largesmp kernel
- do not build for xenU kernel 
  (build failed because PCI support.is not enabled in xenU kernel)

* Wed May 30 2007 Urs Beyerle <urs.beyerle@psi.ch> - 0.9.3.1-9.sl4.psi
- update to 0.9.3.1
- add modules matching ath_rate_*.*o
- madwifi-0.9.2-rhel4.patch no longer needed

* Fri Dec 15 2006 Urs Beyerle <urs.beyerle@psi.ch> - 0.9.2.1-8.sl4.psi
- add madwifi-0.9.2-rhel4.patch from ATrpms
- Introduce epoch since SL4 has 0.9.6 already. :/ 
- update to 0.9.2.1
- many changes in the spec file

* Thu Mar 02 2006 Urs Beyerle <urs.beyerle@psi.ch>
- build UP and SMP kernel modules

* Tue Feb 28 2006 Urs Beyerle <urs.beyerle@psi.ch>
- rebuild without ATrpms specific settings for SL4.

* Tue Feb 21 2006 Axel Thimm <Axel.Thimm@ATrpms.net>
- Split off non-GPL modules into their own subpackage
  to make GPL compliance unambiguous.

* Sat Feb 18 2006 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to today's svn.

* Sun Oct  2 2005 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to today's cvs (0.9.6.0).

* Thu Apr 14 2005 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to today's cvs.

* Sat Jan 22 2005 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to today's cvs.

* Tue Jan  4 2005 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to cvs (0.9.4.12).

* Wed Dec 22 2004 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to cvs.

* Tue Nov  2 2004 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to cvs (0.9.4.11).

* Wed Aug 18 2004 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to cvs (0.9.3.1).

* Mon Jul 26 2004 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to WPA cvs (0.9.2.2-WPA).

* Sun May 30 2004 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to cvs (0.8.5.5).

* Wed Mar 24 2004 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to 0.8.5.4.

* Tue Feb  3 2004 Axel Thimm <Axel.Thimm@ATrpms.net>
- Initial build.
